@@ -93,7 +93,9 @@ ars_DeleteEscalation ars_DeleteField ars_DeleteSchema
 ars_DeleteVUI ars_ExecuteAdminExtension ars_ExecuteProcess
 ars_GetAdminExtension ars_GetEscalation ars_GetFullTextInfo
 ars_GetListGroup ars_GetListSQL ars_GetListUser
-ars_GetListVUI ars_GetServerInfo ars_GetEntryBLOB
+ars_GetListVUI 
+ars_GetServerInfo ars_SetServerInfo
+ars_GetEntryBLOB
 ars_CreateActiveLink ars_CreateAdminExtension
 ars_GetControlStructFields ars_GetVUI
 ars_GetListContainer ars_SetServerPort
@@ -101,9 +103,19 @@ $ars_errstr %ARServerStats %ars_errhash
 ars_decodeStatusHistory ars_APIVersion
 );
 
-$ARS::VERSION   = '1.68';
+$ARS::VERSION   = '1.69';
 $ARS::DEBUGGING = 0;
 
+# definitions required for backwards compatibility
+
+if (!defined &ARS::AR_IMPORT_OPT_CREATE) {
+	eval 'sub AR_IMPORT_OPT_CREATE { 0; }';
+}
+
+if (!defined &ARS::AR_IMPORT_OPT_OVERWRITE) {
+	eval 'sub AR_IMPORT_OPT_OVERWRITE { 1; }';
+}
+
 bootstrap ARS $ARS::VERSION;
 tie $ARS::ars_errstr, ARS::ERRORSTR;
 
