@@ -10,9 +10,9 @@ $header: /u1/project/ARSperl/ARSperl/RCS/support.c,v 1.25 1999/01/04 21:04:27 jc
     This program is free software; you can redistribute it and/or modify
     it under the terms as Perl itself.
 
-    Refer to the file called "Artistic" that accompanies the source distribution
-    of ARSperl (or the one that accompanies the source distribution of Perl
-    itself) for a full description.
+    Refer to the file called "Artistic" that accompanies the source 
+    distribution of ARSperl (or the one that accompanies the source 
+    distribution of Perl itself) for a full description.
 
     Comments to:  arsperl@smurfland.cit.buffalo.edu
                   (this is a *mailing list* and you must be
@@ -21,116 +21,6 @@ $header: /u1/project/ARSperl/ARSperl/RCS/support.c,v 1.25 1999/01/04 21:04:27 jc
     Comments to: arsperl@lurch.cit.buffalo.edu
     Home Page: http://arsinfo.cit.buffalo.edu
 
-    LOG:
-
-$Log: support.c,v $
-Revision 1.33  2000/07/04 14:44:22  jcmurphy
-*** empty log message ***
-
-Revision 1.32  2000/06/01 16:54:03  jcmurphy
-*** empty log message ***
-
-Revision 1.31  2000/05/24 18:05:25  jcmurphy
-primary ars4.5 integration in this checkpoint.
-
-Revision 1.30  2000/02/04 16:20:44  jcmurphy
-*** empty log message ***
-
-Revision 1.29  1999/12/03 22:13:56  jcmurphy
-*** empty log message ***
-
-Revision 1.27  1999/10/03 04:00:27  jcmurphy
-various
-
-Revision 1.26  1999/03/12 07:27:16  jcmurphy
-1.6400 BETA - OO layer and attachments
-
-Revision 1.25  1999/01/04 21:04:27  jcmurphy
-fixed some typos for compiling against 2.x libs
-
-Revision 1.24  1998/12/28 15:46:10  jcmurphy
-v1.62
-
-Revision 1.23  1998/09/18 14:44:15  jcmurphy
-reworked joinschema entry-id handling. added my_strtok routine
-so we can split() the entry-id into the appropriate number of
-parts regardless of whether it is an inner or outter join.
-
-Revision 1.22  1998/09/16 14:16:12  jcmurphy
-fixed bug in perl_ARIndexStruct
-
-Revision 1.21  1998/09/11 17:52:42  jcmurphy
-nothing really. added some ifdef'd out code when i was
-thinking about changing the return values for {limit} key
-to GetField. but i decided against it.
-
-Revision 1.20  1998/04/25 16:00:20  jcmurphy
-removed some debugging code
-
-Revision 1.19  1998/03/31 23:31:06  jcmurphy
-NT patch from  Bill Middleton <wjm@metronet.com>
-
-Revision 1.17  1998/03/30 21:24:45  jcmurphy
-removed unused code
-
-Revision 1.16  1998/03/12 20:46:17  jcmurphy
-fixes to decoding the values that are assigned to a field
-when performing a setfields operation in active links
-and filters.
-
-Revision 1.15  1998/03/11 14:09:25  jcmurphy
-fixed bug in macroParm
-
-Revision 1.14  1998/02/25 19:22:43  jcmurphy
-applied fixes to dup_FieldValueOrArith to handle
-AR_FIELD_CURRENT, FIELD_TRAN and _DB
-
-Revision 1.13  1998/02/13 18:44:34  jcmurphy
-patched BuildEntryIdList by Ulrich Pfeifer <pfeifer@wait.de>
-patch includes strncpy and terminating null to make it
-more robust.
-
-Revision 1.12  1997/12/15 21:25:39  jcmurphy
-/1.53
-
-Revision 1.11  1997/11/10 23:50:36  jcmurphy
-1.5206: added refreshCode to GetCharMenu().
-added ars_GetVUI to EXPORTS in .pm file
-fixed bug in 1.5205's groupList alteration
-
-Revision 1.10  1997/11/04 18:18:19  jcmurphy
-1.5205: perl_permissionsList update
-
-Revision 1.9  1997/10/20 21:00:41  jcmurphy
-5203 beta. code cleanup. winnt additions. malloc/free
-debugging code.
-
-Revision 1.8  1997/10/13 12:24:54  jcmurphy
-cd ..
-removed debugging line
-
-Revision 1.7  1997/10/09 15:21:33  jcmurphy
-code cleaning.
-
-Revision 1.6  1997/10/09 00:48:55  jcmurphy
-1.52: uninit'd var bug fix
-
-Revision 1.5  1997/10/07 14:29:33  jcmurphy
-1.51
-
-Revision 1.4  1997/10/06 13:39:30  jcmurphy
-fix up some compilation warnings
-
-Revision 1.3  1997/10/02 15:39:48  jcmurphy
-1.50beta
-
-Revision 1.2  1997/09/04 00:20:38  jcmurphy
-*** empty log message ***
-
-Revision 1.1  1997/08/05 21:21:05  jcmurphy
-Initial revision
-
-
 */
 
 /* NAME
@@ -484,17 +374,44 @@ NTError(int returncode, NTStatusList status)
 	return ret;
 }
 
+unsigned int
+caseLookUpTypeNumber(TypeMapStruct *t, char *s)
+{
+	int i = 0;
+	if(!t || !CVLD(s)) return TYPEMAP_LAST;
+
+	while(strcasecmp(s, t[i].name) && t[i].number != TYPEMAP_LAST)
+		i++;
+
+	return t[i].number;
+}
+
 char *
 lookUpTypeName(TypeMapStruct *t, unsigned int v)
 {
 	int i = 0;
-	if(t[i].number != v && t[i].number != TYPEMAP_LAST)
+
+	if(!t) return "[unknown]";
+
+	while(t[i].number != v && t[i].number != TYPEMAP_LAST)
 		i++;
 	if(t[i].number == v)
 		return t[i].name;
 	return "[unknown]";
 }
 
+unsigned int
+lookUpServerInfoTypeHint(unsigned int itn)
+{
+	int i = 0;
+
+	while((ServerInfoTypeHints[i].infoTypeNum != itn) &&
+	      (ServerInfoTypeHints[i].infoTypeNum != TYPEMAP_LAST))
+		i++;
+
+        return ServerInfoTypeHints[i].infoTypeType;
+}
+
 unsigned int
 strsrch(register char *s, register char c)
 {
@@ -1111,10 +1028,11 @@ perl_ARActiveLinkActionStruct(ARControlStruct * ctrl, ARActiveLinkActionStruct *
 		hv_store(hash, VNAME("process"), newSVpv(in->u.process, 0), 0);
 		break;
 	case AR_ACTIVE_LINK_ACTION_MESSAGE:
-		hv_store(hash, VNAME("message"),
 #if AR_EXPORT_VERSION >= 4
+		hv_store(hash, VNAME("message"),
 			 perl_ARMessageStruct(ctrl, &(in->u.message)), 0);
 #else
+		hv_store(hash, VNAME("message"),
 			 perl_ARStatusStruct(ctrl, &(in->u.message)), 0);
 #endif
 		break;
